InputState

Struct InputState 

pub struct InputState {
    pub left_mouse_down: bool,
    pub right_mouse_down: bool,
    pub middle_mouse_down: bool,
    pub last_cursor_x: f64,
    pub last_cursor_y: f64,
    pub cursor_x: f64,
    pub cursor_y: f64,
    pub scroll_delta: f32,
    pub egui_wants_pointer: bool,
    pub viewport_rect: ViewportRect,
}
Tracks raw input state for orbit camera control

Fields

left_mouse_down: boolright_mouse_down: boolmiddle_mouse_down: boollast_cursor_x: f64last_cursor_y: f64cursor_x: f64cursor_y: f64scroll_delta: f32egui_wants_pointer: boolviewport_rect: ViewportRect

The central 3D viewport rect in screen pixels; only mouse events inside this area affect the camera

Implementations

Source

impl InputState

pub fn apply_to_camera( &mut self, camera: &mut OrbitCamera, _window_size: [u32; 2], )

Apply accumulated input to camera, then reset deltas. Only applies camera operations when the cursor is inside the 3D viewport area and egui does not want the pointer.